# Examples

These are the DIPY examples. They are built as docs in the DIPY
`examples_built` directory in the documentation.

If you add an example (yes please!), please remember to add it to the
`valid_examples.txt` file located in this directory and to the
`examples_index.rst` file listing in the `doc` directory.
